TurboJPEG: Data Fields - Variables

TurboJPEG 2.0

- Main Page
- Modules
- Data Structures

- Data Structures
- Data Structure Index
- Data Fields

- All
- Variables

All Data Structures Functions Variables Typedefs Enumerations Enumerator Groups

- customFilter : tjtransform
- data : tjtransform
- denom : tjscalingfactor
- h : tjregion
- num : tjscalingfactor
- op : tjtransform
- options : tjtransform
- r : tjtransform
- w : tjregion
- x : tjregion
- y : tjregion